@@ -96,16 +96,19 @@ $redirectURI = $this->config->get('orcid_' . $srv . '_redirect_uri', '');
 				<div class="grid nobreak">
 					<div class="col span4">
 						<label for="first-name">
-							<?php echo Lang::txt('COM_MEMBERS_PROFILE_ORCID_FIRST_NAME'); ?>
+							<?php echo Lang::txt('COM_MEMBERS_PROFILE_ORCID_FIRST_NAME'); ?><span class="required" style="color:red"><?php echo Lang::txt('COM_MEMBERS_SEARCH_ORCID_REQUIRED'); ?></span>
 							<input type="text" id="first-name" name="first-name" value="<?php echo $this->escape($fname); ?>" />
 						</label>
 					</div>
 					<div class="col span4">
 						<label for="last-name">
-							<?php echo Lang::txt('COM_MEMBERS_PROFILE_ORCID_LAST_NAME'); ?>
+							<?php echo Lang::txt('COM_MEMBERS_PROFILE_ORCID_LAST_NAME'); ?><span class="required" style="color:red"><?php echo Lang::txt('COM_MEMBERS_SEARCH_ORCID_REQUIRED'); ?></span>
 							<input type="text" id="last-name" name="last-name" value="<?php echo $this->escape($lname); ?>" />
 						</label>
 					</div>
+					<div id="alert-message" class="col span8" style="display:none">
+							<p style="color:red"><?php echo Lang::txt('COM_MEMBERS_SEARCH_ORCID_ALERT_NAME'); ?></p>
+					</div>
 				</div>
 
 				<input type="hidden" name="base_uri" id="base_uri" value="<?php echo rtrim(Request::base(true), '/'); ?>" />
@@ -116,11 +119,10 @@ $redirectURI = $this->config->get('orcid_' . $srv . '_redirect_uri', '');
 				<div class="grid nobreak">
 					<div class="col span8">
 						<p><?php echo Lang::txt('COM_MEMBERS_PROFILE_ORCID_FILL_AND_SEARCH'); ?></p>
-						<p><?php echo Lang::txt('COM_MEMBERS_PROFILE_ORCID_NOTE_ABOUT_PRIVATE_ORCID'); ?></p>
 					</div>
 					<div class="col span4 omega">
 						<p>
-							<a id="get-orcid-results" class="btn" onclick="<?php echo 'HUB.Orcid.fetchOrcidRecords(\'' . $this->escape($fname) . '\', \'' . $this->escape($lname) . '\');'; ?>"><?php echo Lang::txt('Search ORCID'); ?></a>
+							<a id="get-orcid-results" class="btn"><?php echo Lang::txt('Search ORCID'); ?></a>
 						</p>
 					</div>
 				</div>
